<?php

function squirrelmail_plugin_init_mark_read() {

  global $squirrelmail_plugin_hooks;


  $squirrelmail_plugin_hooks['folders_bottom']['mark_read'] 
     = 'mark_read_show_options';
  $squirrelmail_plugin_hooks['left_main_after_each_folder']['mark_read']
     = 'mark_read_show_link';
  $squirrelmail_plugin_hooks['left_main_after']['mark_read']
     = 'mark_read_show_link_all_read';  

}


function mark_read_show_options() {

  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/mark_read/functions.php');
  else
     include_once('../plugins/mark_read/functions.php');

  mark_read_show_options_do();

}


function mark_read_show_link($parms) {

  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/mark_read/functions.php');
  else
     include_once('../plugins/mark_read/functions.php');

  return mark_read_show_link_do($parms);

}

function mark_read_show_link_all_read() {

  if (defined('SM_PATH'))
     include_once(SM_PATH . 'plugins/mark_read/functions.php');
  else
     include_once('../plugins/mark_read/functions.php');

  return mark_read_do_mark_all_read();
  
}

function mark_read_version() {

  return '1.4.1';

}

?>
